﻿using PetitProgramme.DAO;
using PetitProgramme.Model;
using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Input;
using Xamarin.Forms;

namespace PetitProgramme.ViewModel
{
    public class PeseeAnimalViewModel : BaseViewModel
    {
        /// <summary>
        /// Déclaration des attributs
        /// </summary>
        private List<Elevage> elevages;
        private Elevage elevageSelectionne;
        private string animalNumero;
        private string retourValidation;
        private int animalPoids;
        private Animal animalEncours;
        private String couleurMessage;

        /// <summary>
        /// Déclaration des commandes
        /// </summary>
        public ICommand ValiderNumeroAnimalCommand { get; private set; }
        public ICommand EnregistrerCommand { get; private set; }

        /// <summary>
        /// Constructeur de PeseeAnimalViewModel appelé dans le code behind de PeseeAnimalView
        /// </summary>
        public PeseeAnimalViewModel()
        {
            //Récupération de la liste des élevages et alimentation de la propriété Elevages et donc du Picker correspondant
            ElevageDAO elDAO = new ElevageDAO();
            Elevages = elDAO.getElevages();
            //Instanciation des commandes
            ValiderNumeroAnimalCommand = new Command(ValiderNumeroAnimal, CanValiderNumeroAnimal);
            EnregistrerCommand = new Command(EnregistrerPesee, CanValiderNumeroAnimal);
        }


        /// <summary>
        /// Propriété Elevages en binding avec le Picker de la view
        /// </summary>
        public List<Elevage> Elevages
        {
            get { return elevages; }
            set
            {
                if (elevages != value)
                {
                    elevages = value;
                    OnPropertyChanged();
                }
            }
        }

        /// <summary>
        /// Propriété ElevageSelectionne en binding avec SelectedItem du Picker
        /// </summary>
        public Elevage ElevageSelectionne
        {
            get { return elevageSelectionne; }
            set
            {
                if (elevageSelectionne != value)
                {
                    elevageSelectionne = value;
                    OnPropertyChanged();
                }
            }
        }

        /// <summary>
        /// Propriété AnimalNumero en binding avec l'Entry de la view
        /// </summary>
        public String AnimalNumero
        {
            get { return animalNumero; }
            set
            {
                if (animalNumero != value)
                {
                    animalNumero = value;
                    OnPropertyChanged();
                }
                ((Command)ValiderNumeroAnimalCommand).ChangeCanExecute();
                ((Command)EnregistrerCommand).ChangeCanExecute();
            }
        }

        /// <summary>
        /// Propriété RetourValidation en binding avec le Label dans la view
        /// </summary>
        public String RetourValidation
        {
            get { return retourValidation; }
            set
            {
                if (retourValidation != value)
                {
                    retourValidation = value;
                    OnPropertyChanged();
                }
            }
        }

        /// <summary>
        /// Propriété AnimalPoids en binding avec l'Entry de la view
        /// </summary>
        public int AnimalPoids
        {
            get { return animalPoids; }
            set
            {
                if (animalPoids != value)
                {
                    animalPoids = value;
                    OnPropertyChanged();
                }
            }
        }

        /// <summary>
        /// Propriété CouleurMessage en bindng avec la propriété TextColor du Label
        /// </summary>
        public String CouleurMessage
        {
            get
            {
                return couleurMessage;
            }
            set
            {
                if (couleurMessage != value)
                {
                    couleurMessage = value;
                    OnPropertyChanged();
                }
            }
        }

        private void ValiderNumeroAnimal()
        {
            AnimalDAO anDAO = new AnimalDAO();
            List<Animal> animauxDeLelevage = anDAO.getAnimalByElevage(ElevageSelectionne);
            animalEncours = animauxDeLelevage.Find(a => a.Rfid.Equals(AnimalNumero));
            if (animalEncours != null)
            {
                RetourValidation = "OK";
                CouleurMessage = "Green";
            }
            else
            {
                RetourValidation = "Animal non trouvé sur l'élevage "+ElevageSelectionne.ElevageNom;
                CouleurMessage = "#FF4235";
            }
        }

        private bool CanValiderNumeroAnimal()
        {
            return !String.IsNullOrEmpty(AnimalNumero);
        }

        private void EnregistrerPesee()
        {
            if (animalEncours != null)
            {
                Pesee nouvellePesee = new Pesee();
                nouvellePesee.Animal = animalEncours;
                nouvellePesee.DatePesee = DateTime.Now;
                nouvellePesee.Poids = AnimalPoids;
                PeseeDAO peDAO = new PeseeDAO();
                peDAO.save(nouvellePesee);
            }
        }

    }
}
